
;;; thumbs site-lisp configuration

(add-to-list 'load-path "@SITELISP@")
(require 'image)
(require 'thumbs)
